
package eu.dnetlib.dhp.oa.provision.scholix;

import java.io.IOException;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

import org.apache.solr.common.SolrInputDocument;
import org.apache.spark.api.java.function.MapFunction;

import com.fasterxml.jackson.databind.ObjectMapper;

import eu.dnetlib.dhp.oa.provision.model.SerializableSolrInputDocument;
import eu.dnetlib.dhp.schema.oaf.utils.GraphCleaningFunctions;
import eu.dnetlib.dhp.schema.sx.scholix.*;

public class ScholixToSolr implements MapFunction<String, SolrInputDocument> {
	final static ObjectMapper MAPPER = new ObjectMapper();

	public static SerializableSolrInputDocument toSolrDocument(final String json) {
		try {
			final Scholix input = MAPPER.readValue(json, Scholix.class);
			final SerializableSolrInputDocument output = new SerializableSolrInputDocument();

			fillEntityField(output, input.getSource(), "source");
			fillEntityField(output, input.getTarget(), "target");
			final String cleanDate = GraphCleaningFunctions.cleanDate(input.getPublicationDate());

			if (cleanDate != null)
				output.addField("publication_date", GraphCleaningFunctions.normalizeDate(cleanDate));

			if (input.getRelationship() != null && input.getRelationship().getName() != null)
				output.addField("relation_name", input.getRelationship().getName());
			else
				return null;
			if (input.getRelationship() != null && input.getRelationship().getInverse() != null)
				output.addField("relation_inverse", input.getRelationship().getInverse());

			if (input.getLinkprovider() != null) {
				final List<String> linkProviders = input
					.getLinkprovider()
					.stream()
					.map(ScholixEntityId::getName)
					.filter(Objects::nonNull)
					.collect(Collectors.toList());

				output.addField("link_provider", linkProviders);
			}
			if (input.getPublisher() != null) {
				final List<String> publishers = input
					.getPublisher()
					.stream()
					.map(ScholixEntityId::getName)
					.filter(Objects::nonNull)
					.collect(Collectors.toList());
				output.addField("publisher_name", publishers);
			}

			output.addField("__indexrecordidentifier", input.getIdentifier());
			output.addField("__result", json);
			return output;

		} catch (IOException e) {
			throw new RuntimeException("Error on convert Scholix");
		}
	}

	private static void fillEntityField(final SerializableSolrInputDocument document, final ScholixResource resource,
		final String prefix) {

		document.addField(prefix + "_identifier", resource.getDnetIdentifier());
		document.addField(prefix + "_type", resource.getObjectType());
		document.addField(prefix + "_publication_date", resource.getPublicationDate());
		document.addField(prefix + "_subtype", resource.getObjectSubType());

		List<String> resourcePIDs = resource
			.getIdentifier()
			.stream()
			.map(ScholixIdentifier::getIdentifier)
			.collect(Collectors.toList());
		document.addField(prefix + "_pid", resourcePIDs);

		List<String> resourceSchemas = resource
			.getIdentifier()
			.stream()
			.map(ScholixIdentifier::getSchema)
			.collect(Collectors.toList());
		document.addField(prefix + "_schema", resourceSchemas);

		if (resource.getPublisher() != null) {

			final List<String> publishers = resource
				.getPublisher()
				.stream()
				.map(ScholixEntityId::getName)
				.collect(Collectors.toList());
			if (publishers.size() > 0)
				document.addField(prefix + "_publisher", publishers);
		}

		if (resource.getCollectedFrom() != null) {

			final List<String> collectedFrom = resource
				.getCollectedFrom()
				.stream()
				.map(ScholixCollectedFrom::getProvider)
				.filter(Objects::nonNull)
				.map(ScholixEntityId::getName)
				.collect(Collectors.toList());
			if (collectedFrom.size() > 0)
				document.addField(prefix + "_collected_from", collectedFrom);
		}

	}

	@Override
	public SerializableSolrInputDocument call(String s) throws Exception {
		return toSolrDocument(s);
	}
}
